import { Program } from "@project-serum/anchor";
import { PublicKey } from "@solana/web3.js";
import { IDL } from "./mango_v3_reimbursement";
export const ID = new PublicKey("m3roABq4Ta3sGyFRLdY4LH1KN16zBtg586gJ3UxoBzb");
export class MangoV3ReimbursementClient {
    constructor(provider) {
        this.program = new Program(IDL, ID, provider);
    }
    async decodeTable(group) {
        const ai = await this.program.provider.connection.getAccountInfo(group.table);
        if (!ai) {
            throw new Error(`Table ai cannot be undefined!`);
        }
        const rowSize = this.program._coder.types.typeLayouts.get("Row").span;
        const tableHeaderSize = 40;
        const rows = (ai.data.length - tableHeaderSize) / rowSize;
        return [...Array(rows).keys()].map((i) => {
            const start = tableHeaderSize + i * rowSize;
            const end = start + rowSize;
            return this.program._coder.types.typeLayouts
                .get("Row")
                .decode(ai.data.subarray(start, end));
        });
    }
    reimbursed(reimbursementAccount, tokenIndex) {
        return (reimbursementAccount.reimbursed & (1 << tokenIndex)) !== 0;
    }
    calimTransferred(reimbursementAccount, tokenIndex) {
        return (reimbursementAccount.calimTransferred & (1 << tokenIndex)) !== 0;
    }
}
//# sourceMappingURL=client.js.map